
TODO: TODO_01_47_82_92: keep applying best practices

This item marks all places which are often non-functional changes:
*   making things more "pythonic" 
*   following some conventions
*   adding linters and code auto-formatters
*   generating reports (e.g. test coverage, static analysis, ...)
*   clarifying packaging
*   ...

Project `argrelay` was written to work (without knowing much about Python, for example) and may miss many improvements.

Some relevant items which are already spun off:
*   TODO: TODO_04_84_79_11: reorganize tests for CI
*   TODO: TODO_78_94_31_68: split argrelay into multiple packages
